@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -79,14 +79,16 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Prepare(void *params)
     PCODEC_AV1_ENCODE_SEQUENCE_PARAMS av1SeqParams = static_cast<PCODEC_AV1_ENCODE_SEQUENCE_PARAMS>(encodeParams->pSeqParams);
     ENCODE_CHK_NULL_RETURN(av1SeqParams);
 
+    auto feature = dynamic_cast<Av1BasicFeature *>(m_featureManager->GetFeature(Av1FeatureIDs::basicFeature));
+    ENCODE_CHK_NULL_RETURN(feature);
+
+    feature->m_dualEncEnable = m_dualEncEnable;
+
     ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Prepare(params));
 
     PCODEC_AV1_ENCODE_PICTURE_PARAMS picParams = static_cast<PCODEC_AV1_ENCODE_PICTURE_PARAMS>(encodeParams->pPicParams);
     ENCODE_CHK_NULL_RETURN(picParams);
 
-    auto feature = dynamic_cast<Av1BasicFeature*>(m_featureManager->GetFeature(Av1FeatureIDs::basicFeature));
-    ENCODE_CHK_NULL_RETURN(feature);
-
     uint16_t numTileRows = 0;
     uint16_t numTileColumns = 0;
     RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns,
@@ -144,54 +146,6 @@ MOS_STATUS Av1VdencPipelineXe_M_Base::Destroy()
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS Av1VdencPipelineXe_M_Base::Initialize(void *settings)
-{
-    ENCODE_FUNC_CALL();
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Initialize(settings));
-    ENCODE_CHK_STATUS_RETURN(InitMmcState());
-
-    CODECHAL_DEBUG_TOOL
-    (
-        if (m_debugInterface != nullptr)
-        {
-            MOS_Delete(m_debugInterface);
-        }
-        m_debugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_debugInterface);
-        ENCODE_CHK_NULL_RETURN(m_mediaCopyWrapper);
-        ENCODE_CHK_STATUS_RETURN(
-            m_debugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper));
-
-        if (m_statusReportDebugInterface != nullptr)
-        {
-            MOS_Delete(m_statusReportDebugInterface);
-        }
-        m_statusReportDebugInterface = MOS_New(CodechalDebugInterface);
-        ENCODE_CHK_NULL_RETURN(m_statusReportDebugInterface);
-        ENCODE_CHK_STATUS_RETURN(
-            m_statusReportDebugInterface->Initialize(m_hwInterface, m_codecFunction, m_mediaCopyWrapper));
-    );
-
-
-    ENCODE_CHK_STATUS_RETURN(GetSystemVdboxNumber());
-
-    return MOS_STATUS_SUCCESS;
-}
-
-MOS_STATUS Av1VdencPipelineXe_M_Base::Uninitialize()
-{
-    ENCODE_FUNC_CALL();
-
-    if (m_mmcState != nullptr)
-    {
-        MOS_Delete(m_mmcState);
-    }
-
-    ENCODE_CHK_STATUS_RETURN(Av1VdencPipeline::Uninitialize());
-
-    return MOS_STATUS_SUCCESS;
-}
-
 MOS_STATUS Av1VdencPipelineXe_M_Base::ResetParams()
 {
     ENCODE_FUNC_CALL();
