@@ -142,7 +142,16 @@ MOS_STATUS VpScalabilityMultiPipeNext::Initialize(const MediaScalabilityOption &
     SCALABILITY_CHK_NULL_RETURN(vpScalabilityOption);
     m_scalabilityOption = vpScalabilityOption;
 
-    m_frameTrackingEnabled = m_osInterface->bEnableKmdMediaFrameTracking ? true : false;
+    if (m_hwInterface->m_bIsMediaSfcInterfaceInUse)
+    {
+        m_frameTrackingEnabled = false;
+        VP_PUBLIC_NORMALMESSAGE("Media Frame Tracking is disabled for Media Sfc Interface enalbed.");
+    }
+    else
+    {
+        m_frameTrackingEnabled = m_osInterface->bEnableKmdMediaFrameTracking ? true : false;
+        VP_PUBLIC_NORMALMESSAGE("Media Frame Tracking flag is %d. Not using Meida Sfc Interface.", m_frameTrackingEnabled);
+    }
 
     //virtual engine init with scalability
     MOS_VIRTUALENGINE_INIT_PARAMS veInitParms;
