@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -40,8 +40,6 @@
 #include "UmdStateSeparation.h"
 #endif
 
-
-
 #define MAX_NAME_LEN            100
 
 #define VPHAL_DUMP_OUTPUT_FOLDER                "\\vphaldump\\"
@@ -278,14 +276,23 @@ public:
     virtual MOS_STATUS CopyThenLockResources(
         PMOS_INTERFACE               pOsInterface,
         PVPHAL_SURFACE               pSurface,
+        PVPHAL_SURFACE              &temp2DSurfForCopy,
         bool                         hasAuxSurf,
         bool                         enableAuxDump,
         PMOS_LOCK_PARAMS             pLockFlags,
-        PMOS_RESOURCE                pLockedResource,
+        PMOS_RESOURCE               &pLockedResource,
         VPHAL_SURF_DUMP_SURFACE_DEF *pPlanes,
         uint32_t                    *pdwNumPlanes,
         uint32_t                    *pdwSize,
-        uint8_t                     *&pData);
+        uint8_t                     *&pData,
+        const char                  *psPathPrefix = nullptr,
+        uint64_t                     iCounter = 0);
+
+    virtual void UnlockAndDestroyResource(
+        PMOS_INTERFACE              osInterface,
+        PVPHAL_SURFACE              tempSurf,
+        PMOS_RESOURCE               lockedResource,
+        bool                        bLockSurface);
 
     VPHAL_SURF_DUMP_SPEC    m_dumpSpec;
 
@@ -437,6 +444,7 @@ private:
         uint32_t*                           pdwSize,
         bool                                auxEnable,
         bool                                isDeswizzled);
+
     //!
     //! \brief    Parse dump location
     //! \details  Take dump location strings and break down into individual post-
